From: "tip-bot2 for Ingo Molnar" <tip-bot2@linutronix.de>
To: linux-tip-commits@vger.kernel.org
Cc: Ingo Molnar <mingo@kernel.org>,
Shrikanth Hegde <sshegde@linux.ibm.com>,
x86@kernel.org, linux-kernel@vger.kernel.org
Subject: [tip: sched/core] sched/balancing: Rename find_idlest_cpu() => sched_balance_find_dst_cpu()
Date: Tue, 12 Mar 2024 12:00:18 -0000 [thread overview]
Message-ID: <171024481845.398.6678071993830758312.tip-bot2@tip-bot2> (raw)
In-Reply-To: <20240308111819.1101550-14-mingo@kernel.org>
The following commit has been merged into the sched/core branch of tip:
Commit-ID: 686d148cbb5a1c2891914b8d11147d3c5556a29a
Gitweb: https://git.kernel.org/tip/686d148cbb5a1c2891914b8d11147d3c5556a29a
Author: Ingo Molnar <mingo@kernel.org>
AuthorDate: Fri, 08 Mar 2024 12:18:19 +01:00
Committer: Ingo Molnar <mingo@kernel.org>
CommitterDate: Tue, 12 Mar 2024 12:00:00 +01:00
sched/balancing: Rename find_idlest_cpu() => sched_balance_find_dst_cpu()
Standardize scheduler load-balancing function names on the
sched_balance_() prefix.
Also use 'dst' instead of 'idlest', because it's not really
true that we return the 'idlest' group or CPU, we sort by
idle-exit latency and only return the idlest CPUs from the
lowest-latency set of CPUs.
The true 'idlest' CPUs often remain idle for a long time
and are never returned as long as the system is under-loaded.
Signed-off-by: Ingo Molnar <mingo@kernel.org>
Reviewed-by: Shrikanth Hegde <sshegde@linux.ibm.com>
Link: https://lore.kernel.org/r/20240308111819.1101550-14-mingo@kernel.org
---
kernel/sched/fair.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/kernel/sched/fair.c b/kernel/sched/fair.c
index d0c3a09..4b3c4a1 100644
--- a/kernel/sched/fair.c
+++ b/kernel/sched/fair.c
@@ -7160,7 +7160,7 @@ sched_balance_find_dst_group_cpu(struct sched_group *group, struct task_struct *
return shallowest_idle_cpu != -1 ? shallowest_idle_cpu : least_loaded_cpu;
}
-static inline int find_idlest_cpu(struct sched_domain *sd, struct task_struct *p,
+static inline int sched_balance_find_dst_cpu(struct sched_domain *sd, struct task_struct *p,
int cpu, int prev_cpu, int sd_flag)
{
int new_cpu = cpu;
@@ -7936,7 +7936,7 @@ compute_energy(struct energy_env *eenv, struct perf_domain *pd,
* NOTE: Forkees are not accepted in the energy-aware wake-up path because
* they don't have any useful utilization data yet and it's not possible to
* forecast their impact on energy consumption. Consequently, they will be
* placed by find_idlest_cpu() on the least loaded CPU, which might turn out
* to be energy-inefficient in some use-cases. The alternative would be to
* bias new tasks towards specific types of CPUs first, or to try to infer
* their util_avg from the parent task, but those heuristics could hurt
@@ -8201,7 +8201,7 @@ select_task_rq_fair(struct task_struct *p, int prev_cpu, int wake_flags)
if (unlikely(sd)) {
/* Slow path */
- new_cpu = find_idlest_cpu(sd, p, cpu, prev_cpu, sd_flag);
+ new_cpu = sched_balance_find_dst_cpu(sd, p, cpu, prev_cpu, sd_flag);
} else if (wake_flags & WF_TTWU) { /* XXX always ? */
/* Fast path */
new_cpu = select_idle_sibling(p, prev_cpu, new_cpu);
next prev parent reply other threads:[~2024-03-12 12:00 UTC|newest]
Thread overview: 33+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-03-08 11:18 [PATCH -v1 00/13] sched/balancing: Standardize the naming of scheduler load-balancing functions Ingo Molnar
2024-03-08 11:18 ` [PATCH 01/13] sched/balancing: Rename run_rebalance_domains() => sched_balance_softirq() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 02/13] sched/balancing: Rename scheduler_tick() => sched_tick() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 03/13] sched/balancing: Rename trigger_load_balance() => sched_balance_trigger() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 04/13] sched/balancing: Rename rebalance_domains() => sched_balance_domains() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 05/13] sched/balancing: Rename load_balance() => sched_balance_rq() Ingo Molnar
2024-03-11 8:17 ` Shrikanth Hegde
2024-03-12 10:27 ` Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 06/13] sched/balancing: Rename find_busiest_queue() => find_src_rq() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] sched/balancing: Rename find_busiest_queue() => sched_balance_find_src_rq() tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 07/13] sched/balancing: Rename find_src_rq() " Ingo Molnar
2024-03-08 13:51 ` Vincent Guittot
2024-03-08 17:49 ` Ingo Molnar
2024-03-08 11:18 ` [PATCH 08/13] sched/balancing: Rename find_busiest_group() => sched_balance_find_src_group() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 09/13] sched/balancing: Rename update_blocked_averages() => sched_balance_update_blocked_averages() Ingo Molnar
2024-03-11 6:42 ` Honglei Wang
2024-03-12 10:36 ` Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 10/13] sched/balancing: Rename newidle_balance() => sched_balance_newidle() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 11/13] sched/balancing: Rename find_idlest_group_cpu() => sched_balance_find_dst_group_cpu() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 12/13] sched/balancing: Rename find_idlest_group() => sched_balance_find_dst_group() Ingo Molnar
2024-03-12 12:00 ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 13/13] sched/balancing: Rename find_idlest_cpu() => sched_balance_find_dst_cpu() Ingo Molnar
2024-03-12 12:00 ` tip-bot2 for Ingo Molnar [this message]
2024-03-08 11:25 ` [PATCH -v1 00/13] sched/balancing: Standardize the naming of scheduler load-balancing functions Ingo Molnar
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=171024481845.398.6678071993830758312.tip-bot2@tip-bot2 \
--to=tip-bot2@linutronix.de \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@kernel.org \
--cc=sshegde@linux.ibm.com \
--cc=x86@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -7936,7 +7936,7 @@ compute_energy(struct energy_env *eenv, struct perf_domain *pd,
* they don't have any useful utilization data yet and it's not possible to
* forecast their impact on energy consumption. Consequently, they will be
- * placed by find_idlest_cpu() on the least loaded CPU, which might turn out
+ * placed by sched_balance_find_dst_cpu() on the least loaded CPU, which might turn out
* to be energy-inefficient in some use-cases. The alternative would be to
* bias new tasks towards specific types of CPUs first, or to try to infer
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®